[hide private]
[frames] | no frames]

[ Module Hierarchy | Class Hierarchy ]

# Module Hierarchy

- pywurfl: pywurfl - Python tools for processing and querying the Wireless Universal Resource File (WURFL)
  - pywurfl.algorithms: pywurfl search algorithms
  - pywurfl.exceptions: Exception Classes
  - pywurfl.ql: pywurfl Query Language
  - pywurfl.serialize: pywurfl WURFL class hierarchy serializer
  - pywurfl.wurflprocessor: WURFL processing utility.
- wurfl2python: WURFL <wurfl.sourceforge.net> conversion utility